@@ -13,7 +13,7 @@
 
 class KJob;
 
-class JobTrackerWidget: public QFrame, public Ui::JobTrackerWidget
+class JobTrackerWidget : public QFrame, public Ui::JobTrackerWidget
 {
     Q_OBJECT
 
@@ -21,7 +21,7 @@ public:
     explicit JobTrackerWidget(QWidget *parent = nullptr);
 };
 
-class JobTracker: public KAbstractWidgetJobTracker
+class JobTracker : public KAbstractWidgetJobTracker
 {
     Q_OBJECT
 
@@ -36,18 +36,18 @@ public Q_SLOTS:
     void unregisterJob(KJob *job) override;
 
 protected Q_SLOTS:
-    void description(KJob *job, const QString &title, const QPair< QString, QString > &f1, const QPair< QString, QString > &f2)  override;
+    void description(KJob *job, const QString &title, const QPair<QString, QString> &f1, const QPair<QString, QString> &f2) override;
     void infoMessage(KJob *job, const QString &message) override;
     void warning(KJob *job, const QString &message) override;
 
-    void percent(KJob *job, unsigned long  percent) override;
+    void percent(KJob *job, unsigned long percent) override;
 
 private Q_SLOTS:
     void resetUi();
 
 private:
-    JobTrackerWidget *m_ui;
-    QSet<KJob*> m_jobs;
+    JobTrackerWidget *m_ui = nullptr;
+    QSet<KJob *> m_jobs;
 };
 
 #endif // JOBTRACKER_H
